'use strict';
const auth = require('../../auth');
const domains = require('../../lib/domains');
const notice = require('../../lib/notice');
const assertPkg = require('../../lib/package-json').assert;

/**
 * List the available domains for this site
 * @param argv
 */
const list = (argv) => {
    if (argv.siteName === undefined) {
        console.log('This project is not initialised. Did you forget to \'linc init\'?');
        process.exit(255);
    }

    assertPkg();

    notice();

    console.log('Please wait...');

    auth(argv.accessKey, argv.secretKey)
        .then(auth_params => domains.getAvailableDomains(argv.siteName, auth_params))
        .then(result => domains.showAvailableDomains(result))
        .catch(err => console.log(`Oops, something went wrong:\n${err}.`));
};

exports.command = 'list';
exports.desc = 'List available domain names';
exports.handler = (argv) => {
    list(argv);
};
